@@ -1,6 +1,6 @@
 from .parser import parse
 from .exceptions import SNSinteractionException, SNSserverException
-from .records import SNSuserRecord
+from .records import get_user_record
 from .objects import SNSinteraction, SNScontent
 
 import socket
@@ -25,7 +25,7 @@ def request(type, action, content=None, **headers):
     try:
         address = interaction.headers['To'].split('@')[1]
     except:
-        address = SNSuserRecord.provider
+        address = get_user_record().provider
 
     conn = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     conn.connect((address, SNS_PORT))
@@ -59,7 +59,7 @@ def request(type, action, content=None, **headers):
 def user(action, To, content=None, **headers):
     encrypted_content = content
 
-    headers['From'] = 'user:' + SNSuserRecord.identifier
+    headers['From'] = 'user:' + get_user_record().identifier
     headers['To'] = To
 
     interaction_object = request('USER', action, encrypted_content, **headers)
@@ -69,7 +69,7 @@ def user(action, To, content=None, **headers):
 def group(action, To, content=None, **headers):
     encrypted_content = content
 
-    headers['From'] = 'user:' + SNSuserRecord.identifier
+    headers['From'] = 'user:' + get_user_record().identifier
     headers['To'] = To
 
     interaction_object = request('GROUP', action, encrypted_content, **headers)
@@ -79,7 +79,7 @@ def group(action, To, content=None, **headers):
 def post(action, To, content=None, **headers):
     encrypted_content = content
 
-    headers['From'] = 'user:' + SNSuserRecord.identifier
+    headers['From'] = 'user:' + get_user_record().identifier
     headers['To'] = To
 
     interaction_object = request('POST', action, encrypted_content, **headers)
@@ -89,7 +89,7 @@ def post(action, To, content=None, **headers):
 def reaction(action, To, content=None, **headers):
     encrypted_content = content
 
-    headers['From'] = 'user:' + SNSuserRecord.identifier
+    headers['From'] = 'user:' + get_user_record().identifier
     headers['To'] = To
 
     interaction_object = request('REACTION', action, encrypted_content, **headers)
